import os
import psutil

from utils.log.trans_log import trans_print


def get_cpu_count():
    return psutil.cpu_count()


def get_available_cpu_count_with_percent(percent: float = 1):
    cpu_count = get_cpu_count()
    return int(cpu_count * percent)


def get_file_size(file_path):
    return os.path.getsize(file_path)


def get_available_memory_with_percent(percent: float = 1):
    memory_info = psutil.virtual_memory()
    return int(memory_info.available * percent)


def get_max_file_size(file_paths: list[str]):
    max_size = 0
    for file_path in file_paths:
        file_size = get_file_size(file_path)
        if file_size > max_size:
            max_size = file_size
    return max_size


def use_files_get_max_cpu_count(file_paths: list[str], memory_percent: float = 1 / 9, cpu_percent: float = 1 / 3):
    max_file_size = get_max_file_size(file_paths)
    free_memory = get_available_memory_with_percent(memory_percent)
    count = int(free_memory / max_file_size)
    max_cpu_count = get_available_cpu_count_with_percent(cpu_percent)
    result = count if count <= max_cpu_count else max_cpu_count
    trans_print("总文件数:", len(file_paths), ",获取最大文件大小:", str(round(max_file_size / 2 ** 20, 2)) + "M",
                "可用内存:", str(get_available_memory_with_percent(1) / 2 ** 20) + "M",
                "总CPU数:", get_cpu_count(), "CPU可用数量:", max_cpu_count,
                ",最终确定使用进程数:", result)
    return result


if __name__ == '__main__':
    from utils.file.trans_methods import read_files
    import datetime

    read_path = r"Z:\collection_data\1进行中\密马风电场-山西-大唐\收资数据\scada\秒级数据"
    begin = datetime.datetime.now()
    all_files = read_files(read_path)
    print(datetime.datetime.now() - begin)
    count = use_files_get_max_cpu_count(all_files)

    print(count)

    print(get_available_memory_with_percent(1) / 2 ** 20)
    print(get_available_memory_with_percent(2 / 3) / 2 ** 20)

    begin = datetime.datetime.now()
    print(len(all_files))
    print(get_max_file_size(all_files) / 2 ** 20)
    print(datetime.datetime.now() - begin)
